from langchain_community.tools.gitlab.prompt import (
    COMMENT_ON_ISSUE_PROMPT,
    CREATE_FILE_PROMPT,
    CREATE_PULL_REQUEST_PROMPT,
    DELETE_FILE_PROMPT,
    GET_ISSUE_PROMPT,
    GET_ISSUES_PROMPT,
    READ_FILE_PROMPT,
    UPDATE_FILE_PROMPT,
)

__all__ = [
    "GET_ISSUES_PROMPT",
    "GET_ISSUE_PROMPT",
    "COMMENT_ON_ISSUE_PROMPT",
    "CREATE_PULL_REQUEST_PROMPT",
    "CREATE_FILE_PROMPT",
    "READ_FILE_PROMPT",
    "UPDATE_FILE_PROMPT",
    "DELETE_FILE_PROMPT",
]
