from langchain_community.embeddings.huggingface_hub import (
    DEFAULT_MODEL,
    VALID_TASKS,
    HuggingFaceHubEmbeddings,
)

__all__ = ["DEFAULT_MODEL", "VALID_TASKS", "HuggingFaceHubEmbeddings"]
