from langchain_community.embeddings.octoai_embeddings import (
    DEFAULT_EMBED_INSTRUCTION,
    DEFAULT_QUERY_INSTRUCTION,
    OctoAIEmbeddings,
)

__all__ = ["DEFAULT_EMBED_INSTRUCTION", "DEFAULT_QUERY_INSTRUCTION", "OctoAIEmbeddings"]
