from langchain_community.tools.clickup.prompt import (
    CLICKUP_FOLDER_CREATE_PROMPT,
    CLICKUP_GET_ALL_TEAMS_PROMPT,
    CLICKUP_GET_FOLDERS_PROMPT,
    CLICKUP_GET_LIST_PROMPT,
    CLICKUP_GET_SPACES_PROMPT,
    CLICKUP_GET_TASK_ATTRIBUTE_PROMPT,
    CLICKUP_GET_TASK_PROMPT,
    CLICKUP_LIST_CREATE_PROMPT,
    CLICKUP_TASK_CREATE_PROMPT,
    CLICKUP_UPDATE_TASK_ASSIGNEE_PROMPT,
    CLICKUP_UPDATE_TASK_PROMPT,
)

__all__ = [
    "CLICKUP_TASK_CREATE_PROMPT",
    "CLICKUP_LIST_CREATE_PROMPT",
    "CLICKUP_FOLDER_CREATE_PROMPT",
    "CLICKUP_GET_TASK_PROMPT",
    "CLICKUP_GET_TASK_ATTRIBUTE_PROMPT",
    "CLICKUP_GET_ALL_TEAMS_PROMPT",
    "CLICKUP_GET_LIST_PROMPT",
    "CLICKUP_GET_FOLDERS_PROMPT",
    "CLICKUP_GET_SPACES_PROMPT",
    "CLICKUP_GET_SPACES_PROMPT",
    "CLICKUP_UPDATE_TASK_PROMPT",
    "CLICKUP_UPDATE_TASK_ASSIGNEE_PROMPT",
]
