from langchain_community.utilities.merriam_webster import (
    MERRIAM_WEBSTER_API_URL,
    MERRIAM_WEBSTER_TIMEOUT,
    MerriamWebsterAPIWrapper,
)

__all__ = [
    "MERRIAM_WEBSTER_API_URL",
    "MERRIAM_WEBSTER_TIMEOUT",
    "MerriamWebsterAPIWrapper",
]
